Documentation for repoze.workflow
=================================

:mod:`repoze.workflow` is a content workflow system.

A :mod:`repoze.workflow` configuration defines *states* and
*transitions*.  A state is an "end point" associated with a piece of
content.  A transition is a path from one state to another state
(unidirectional).

.. toctree::
   :maxdepth: 2

   configuration.rst
   usage.rst
   api.rst
   glossary.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
